#!/bin/sh
# To use LAVA with fast models please follow this script. The script assumes
# you can connect to the Linaro license server. To connect to the server you
# need to add one entry to /etc/hosts:
#   127.0.0.1   flexlm.linaro.org
# and keep this program active while 
#   ssh -L 8224:localhost:8224 -L 18224:localhost:18224 -N portfwd@23.21.178.170

# Let's create a workspace for this example. LAVA uses workspaces to store
# configuration files. LAVA workspaces work like version control directories,
# as long as you are inside a sub-directory of the workspace you can interact
# with it directly

# To create a workspace use the 'lava init' command, like this:
lava-dev init demo-rtsm && cd demo-rtsm

# To use rtsm we'll need linaro-image-tools. Currently we need a special
# flavour that knows how to build images for fast models.
if [ ! -d /opt/linaro ]; then
    sudo mkdir -p /opt/linaro
fi
if [ ! -w /opt/linaro ]; then
    sudo chown $(id -u) /opt/linaro
fi
#if [ ! -e /opt/linaro/lmc-fastmodels ]; then
    # TODO: publish the branch that fixes permissions in l-m-c output, the
    # branch below is _NOT_ going to work, it's based on the older version of
    # lmc+fast models branch.

    #sudo apt-get install python-distutils-extra
    #dir=$(mktemp -d)
    #bzr branch lp:~zkrynicki/linaro-image-tools/fastmodel-directory-fixes $dir --use-existing-dir
    #virtualenv --system-site-packages /opt/linaro/lmc-fastmodels/
    #. /opt/linaro/lmc-fastmodels/bin/activate
    #cd $dir
    #python setup.py install
    #cd -
    #deactivate
    #rm -rf $dir
#fi

# We will also need to register the fast model executable. If you have another
# binary somewhere you can use that instead.
lava-dev software use \
    /opt/arm/RTSM_A15x14-A7x14_VE/bin/RTSM_VE_Cortex-A15x4-A7x4 \
    -E ARMLMD_LICENSE_FILE=8224@flexlm.linaro.org
# ^^ NOTE: This step is not needed if you have that executable in the PATH and you
# have set the ARMLMD_LICENSE_FILE

# Next, let's add a virtual device using the 'rtsm' backend.
lava-dev device add rtsm-vexpress-a15x4-a7x4 \
    --controller rtsm \
    --name "quad core fast model (big.LITTLE)" \
    --configuration=rtsm_binary=RTSM_VE_Cortex-A15x4-A7x4

lava-dev device add rtsm-vexpress-a15x1-a7x1 \
    --controller rtsm \
    --name "single core fast model (big.LITTLE)" \
    --configuration=rtsm_binary=RTSM_VE_Cortex-A15x1-A7x1
# ^^NOTE: You can have many devices (both physical and virtual). Each device
# needs a unique name (here rtsm-vexpress-a15x4-a7x4) and a controller.
# The controller can also define additional configuration options. The rtsm
# controller defines the mandatory rtsm_binary parameter that tells LAVA the
# name of the fast model executable to use with this device.

# XXX: you will need a prebuilt image, check the scenario for details

# Finally, we can run an example scenario. The scenario describes that we'll
# load big little image onto the target, run the 'stream' test and save it to
# stream-results.json
lava-dev --verbose scenario run \
    ../scenarios/rtsm-prebuilt-stream.json \
    --target rtsm-vexpress-a15x4-a7x4 \
    --output .
# NOTE ^^: That's it! Remember that each lava command, or sub command has a
# --help option. Start with lava --help!
