#!/bin/sh
# To use LAVA  with Qemu please follow this script. The script assumes you are
# using Ubuntu Precise (12.04), earlier versions may work but have not been
# tested.

# Let's create a workspace for this example. LAVA uses workspaces to store
# configuration files. LAVA workspaces work like version control directories,
# as long as you are inside a sub-directory of the workspace you can interact
# with it directly

# To create a workspace use the 'lava init' command, like this:
lava-dev init demo-qemu && cd demo-qemu

# To use qemu we'll need qemu-system package (or better yet, the much better
# version from Linaro PPA). You will also need linaro-image-tools to build
# bootable images.
sudo apt-get install qemu-system linaro-image-tools

# Next, let's add a virtual device using the 'qemu' controller
lava-dev device add qemu-beaglexm \
    --controller qemu \
    --name "Virtual Beagle XM" \
    --configuration=qemu_system=qemu-system-arm \
    --configuration=qemu_machine=beaglexm

# ^^NOTE: You can have many devices (both physical and virtual). Each device
# needs a unique name (here qemu-beaglexm) and a controller.
# The controller can also define additional configuration options. The qemu
# controller defines the mandatory qemu_system and qemu_machine parameters that
# tell LAVA which qemu-system binary to use and which emulated machine to
# select

# Finally, we can run an example scenario. The scenario describes that we'll
# load big little image onto the target, run the 'stream' test and save it to
# stream-results.json
lava-dev --verbose scenario run \
    ../scenarios/omap3-partial-stream.json \
    --target qemu-beaglexm \
    --output /tmp/
# NOTE ^^: That's it! Remember that each lava command, or sub command has a
# --help option. Start with lava --help!
