#!/bin/sh
# Copyright (C) 2011-2012 Linaro Limited
#
# Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
#
# This file is part of lava-core
#
# lava-core is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License version 3
# as published by the Free Software Foundation
#
# lava-core is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with lava-core.  If not, see <http://www.gnu.org/licenses/>.

# XXX IMPORTANT XXX
# This script is automatically processed and all commends and the needless
# whitespace is discarded INCLUDING ALL NEWLINES. This means that all commands
# MUST be terminated by a semicolon. In fact the whole script is "inlined" to
# one long line and literally typed over the serial line.
# XXX IMPORTANT XXX

# This simple function can be piped to to slow down the output to something
# around 9200 bod assuming the actual line speed is 115200 bod. It only makes
# sense when used with _lava_read as the delay is calculated for the length of
# each output line that _lava_read produces.
_lava_slow() {
  while read LINE; do
    echo "$LINE";
    sleep 0.05;
  done;
};


# Read an arbitrary file from disk and dump it as a hex
_lava_read() {
  if [ -f "$1" ]; then
    echo "data";
    od --output-duplicates --format=x1 "$1"; # | _lava_slow;
    echo "ok";
  else
    echo "error";
  fi;
};


lava_agent() {
  local spool=/tmp/lava-agent;
  local count=0;
  rm -rf $spool;
  mkdir $spool;
  # A small trick to make sure our exact match for 'lava-agent-ready' is not
  # coming from our typing
  echo "lava-agent READY" | tr 'READY' 'ready';
  while :; do
    echo -n "lava-agent: ";
    read LINE;
    # Skip empty lines, we cannot do this in the case/esac below because we'd
    # have to quote an empty string and that quote gets discarded by shlex
    if [ "x$LINE" = "x" ]; then
      continue;
    fi;
    case "$LINE" in
      invoke)
        echo -n "parameter: ";
        read COMMAND;
        count=$(expr $count + 1);
        $COMMAND >$spool/$count.out 2>$spool/$count.err;
        echo -n "$?" > $spool/$count.code;
        echo "ok";
        ;;
      return-code)
        _lava_read $spool/$count.code;
        ;;
      stdout)
        _lava_read $spool/$count.out;
        ;;
      stderr)
        _lava_read $spool/$count.err;
        ;;
      read)
        echo -n "parameter: ";
        read PATHNAME;
        _lava_read $PATHNAME;
        ;;
      exit)
        echo "ok";
        break;
        ;;
       help)
         echo "invoke      - start a program";
         echo "return-code - return code of most recent invoke";
         echo "stdout      - hex dump of most recent invoke output steram";
         echo "stderr      - hex dump of most recent invoke error stream";
         echo "read        - hex dump of arbitrary file";
         echo "exit        - stop the agent";
         ;;
      *)
        echo "error";
        ;;
    esac;
  done;
};

lava_agent;
