# Copyright (C) 2011-2012 Linaro Limited
#
# Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
#
# This file is part of lava-core
#
# lava-core is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License version 3
# as published by the Free Software Foundation
#
# lava-core is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with lava-core.  If not, see <http://www.gnu.org/licenses/>.

from __future__ import absolute_import

"""
lava.core.commands.init
=======================
"""

from lava.core.commands import Command
from lava.core.errors import CommandError
from lava.core.workspace import Workspace


class init(Command):
    """
    Create a LAVA workspace
    """

    @classmethod
    def register_arguments(cls, parser):
        parser.add_argument(
            "location",
            nargs="?",
            metavar="LOCATION",
            default=".",
            help="Location of the workspace")

    def invoke(self):
        try:
            workspace = Workspace.find(self.args.location)
        except LookupError:
            pass
        else:
            raise CommandError(
                "There is an existing workspace in the way: {0}".format(
                    workspace._lava_dir))
        try:
            workspace = Workspace.create(self.args.location)
        except OSError as exc:
            raise CommandError(
                "Cannot create workspace: {0}".format(exc))
        else:
            self.say(
                "Initialized new workspace at {0}".format(workspace._lava_dir))
