# Copyright (C) 2011-2012 Linaro Limited
#
# Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
#
# This file is part of lava-core
#
# lava-core is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License version 3
# as published by the Free Software Foundation
#
# lava-core is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with lava-core.  If not, see <http://www.gnu.org/licenses/>.

from __future__ import absolute_import

"""
lava.core.errors
================

Common error classes with fuzzy meaning
"""


class PluginLookupError(LookupError):
    """
    Error raised when a plugin cannot be found
    """


class PluginLoadError(ImportError):
    """
    Error raised when a plugin cannot be loaded
    """


class UnrecoverableProblem(Exception):
    """
    Something that we cannot recover from.

    Aborts processing of the rest of the scenario.
    """


class SemanticProblem(Exception):
    """
    Something does not make sense
    """


class Timeout(UnrecoverableProblem):
    """
    Something has timed out
    """


class PreconditionFailed(SemanticProblem):
    """
    Unable to do something, precondition failed
    """


class CommandError(Exception):
    """
    Raise this from a Command's invoke() method to display an error nicely.

    `lava` will exit with a status of 1 if this is raised.
    """


class AgentError(UnrecoverableProblem):
    """
    Exception raised when agent request fails
    """
