# Copyright (C) 2011-2012 Linaro Limited
#
# Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
#
# This file is part of lava-core
#
# lava-core is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License version 3
# as published by the Free Software Foundation
#
# lava-core is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with lava-core.  If not, see <http://www.gnu.org/licenses/>.

from __future__ import absolute_import

"""
lava.core.session
=================
"""

from lava.core.utils import Scratch, Network
from lava.core.logging import LoggingMixIn


class Session(LoggingMixIn):
    """
    Helper for managing configuration and resources
    """

    def __init__(self, environment):
        """
        Create a test session
        """
        self._environment = environment
        # NOTE: this is the mutable container for arbitrary extra state
        self.state = {}
        # TODO: customize Scratch based on environment settings
        self._scratch = Scratch(prefix='lava.session.')
        self._network = Network(
            self._scratch,
            http_proxy=environment["network"]["proxy"]["http"].value,
            https_proxy=environment["network"]["proxy"]["https"].value)

    @property
    def environment(self):
        """
        :class:`lava.core.environment.Environment` object of this session
        """
        return self._environment

    @property
    def scratch(self):
        """
        :class:`lava.core.utils.Scratch` object of this session
        """
        return self._scratch

    @property
    def network(self):
        """
        :class:`lava.core.utils.Network` object of this session
        """
        return self._network

    def __enter__(self):
        return self

    def __exit__(self, traceback, exc_type, exc_value):
        self._scratch.cleanup()
