#!/usr/bin/env python
# Copyright (C) 2011-2012 Linaro Limited
#
# Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
#
# This file is part of lava-core
#
# lava-core is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License version 3
# as published by the Free Software Foundation
#
# lava-core is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with lava-core.  If not, see <http://www.gnu.org/licenses/>.

from setuptools import setup, find_packages

import versiontools_support


setup(
    name='lava-core',
    version=":versiontools:lava.core:__version__",
    author="Zygmunt Krynicki",
    author_email="zygmunt.krynicki@linaro.org",
    namespace_packages=['lava'],
    packages=find_packages(),
    description="Monolithic core for LAVA",
    long_description=open("README").read(),
    url='https://launchpad.net/lava-core',
    license="LGPLv3, GPLv3",
    test_suite="unittest2.collector",
    entry_points="""
    [console_scripts]
    lava-dev = lava.core.main:LavaDispatcher.run
    [lava_dev.commands]
    init = lava.core.commands.init:init
    device = lava.core.commands.device:device
    software = lava.core.commands.software:software
    scenario = lava.core.commands.scenario:scenario
    auth = lava.core.commands.auth:auth [auth]
    help = lava.core.commands.help:help
    [lava_dev.auth.commands]
    add = lava.core.commands.auth:add [auth]
    [lava.scenario.commands]
    run = lava.core.commands.scenario:run
    check = lava.core.commands.scenario:check
    [lava.device.commands]
    list = lava.core.commands.device:list_devices
    add = lava.core.commands.device:add_device
    [lava.software.commands]
    list = lava.core.commands.software:list_software
    use = lava.core.commands.software:use_software
    revert = lava.core.commands.software:revert_software
    [lava.controllers.devices]
    qemu = lava.core.controllers.devices.qemu:QemuDeviceController
    rtsm = lava.core.controllers.devices.rtsm:RtsmDeviceController
    [lava.controllers.software]
    linaro-media-create = lava.core.controllers.software.lmc:LinaroMediaCreateController
    telnet = lava.core.controllers.software.telnet:TelnetController
    """,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        ("License :: OSI Approved :: GNU Library or Lesser General Public"
         " License (LGPL)"),
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Topic :: Software Development :: Testing",
    ],
    extras_require={'auth': ['keyring']},
    install_requires=[
        'pexpect >= 2.3',
        'requests',
        'argparse >= 1.1',
        'json-document >= 0.8',
        'json-schema-validator',
    ],
    tests_require=[
        'mocker >= 1.0',
        'unittest2',
    ],
    zip_safe=True)
